Intro
=====

This Bandit Visualization module provides an easy-to-use library for
implementing and visualizing various Bandit algorithms and environments
in machine learning. If you are looking for the following, this library
is not for you:

-  You want something fast and efficient
-  You want a tool to run very large simulations

It is good to use if you want to

-  Visualize your algorithms in various ways
-  Quickly make nice looking graphs
-  Have the support of a super-straightforward minilanguage
-  Have a command-line tool and a module you can import

The library is implemented in python3. This library is dependent also on
the following modules, and you must have them installed to run this:

-  pyyaml (text parsing)
-  numpy (math)
-  scipy (stats)
-  matplotlib (creating graphs)

Run files using

::

    banditvis path/to/your/file.txt

Get syntax help with

::

    banditvis -h